From f0daf3e133d34786b72c08769451bd0ca3eed8c3 Mon Sep 17 00:00:00 2001
From: Tim van Dijen <tvdijen@gmail.com>
Date: Sun, 21 Oct 2018 21:37:00 +0200
Subject: [PATCH] Fix wording;  it did not describe what function does

---
 lib/SimpleSAML/Utils/HTTP.php | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/lib/SimpleSAML/Utils/HTTP.php b/lib/SimpleSAML/Utils/HTTP.php
index 81203e9f4..da6ec639d 100644
--- a/lib/SimpleSAML/Utils/HTTP.php
+++ b/lib/SimpleSAML/Utils/HTTP.php
@@ -638,16 +638,16 @@ class HTTP
     /**
      * Retrieve the first element of the URL path.
      *
      * @param boolean $trailingslash Whether to add a trailing slash to the element or not. Defaults to true.
      *
      * @return string The first element of the URL path, with an optional, trailing slash.
      *
      * @author Andreas Solberg, UNINETT AS <andreas.solberg@uninett.no>
      */
-    public static function getFirstPathElement($trailingslash = true)
+    public static function getFirstPathElement($leadingSlash = true)
     {
         if (preg_match('|^/(.*?)/|', $_SERVER['SCRIPT_NAME'], $matches)) {
-            return ($trailingslash ? '/' : '').$matches[1];
+            return ($leadingSlash ? '/' : '').$matches[1];
         }
         return '';
     }
@@ -638,16 +638,16 @@ class HTTP
      * Retrieve the first element of the URL path.
      *
-     * @param boolean $trailingslash Whether to add a trailing slash to the element or not. Defaults to true.
+     * @param boolean $leadingSlash Whether to add a leading slash to the element or not. Defaults to true.
      *
@@ -638,16 +638,16 @@ class HTTP
      *
-     * @return string The first element of the URL path, with an optional, trailing slash.
+     * @return string The first element of the URL path, with an optional, leading slash.
      *
      * @author Andreas Solberg, UNINETT AS <andreas.solberg@uninett.no>
-- 
GitLab